from sql import func_generic as generic

class sum(generic):
    pass

class count(generic):
    pass

